@@ -30,12 +30,15 @@ LTC = Coin("LTC")
 MANA = Coin("MANA")
 MCO = Coin("MCO")
 MKR = Coin("MKR")
+NEAR = Coin("NEAR")
 NEO = Coin("NEO")
 OMG = Coin("OMG")
 ONT = Coin("ONT")
 PAXG = Coin("PAXG")
 QTUM = Coin("QTUM")
 REN = Coin("REN")
+SKL = Coin("SKL")
+STX = Coin("STX")
 UNI = Coin("UNI")
 USDC = Coin("USDC")
 USDT = Coin("USDT")
