@@ -67,6 +67,8 @@ MANA_CRO = Pair("MANA_CRO", price_precision=3, quantity_precision=2)
 MANA_USDT = Pair("MANA_USDT", price_precision=4, quantity_precision=2)
 MKR_CRO = Pair("MKR_CRO", price_precision=2, quantity_precision=3)
 MKR_USDT = Pair("MKR_USDT", price_precision=2, quantity_precision=6)
+NEAR_CRO = Pair("NEAR_CRO", price_precision=3, quantity_precision=2)
+NEAR_USDT = Pair("NEAR_USDT", price_precision=4, quantity_precision=2)
 NEO_BTC = Pair("NEO_BTC", price_precision=6, quantity_precision=3)
 NEO_CRO = Pair("NEO_CRO", price_precision=3, quantity_precision=2)
 NEO_USDT = Pair("NEO_USDT", price_precision=3, quantity_precision=4)
@@ -82,6 +84,7 @@ QTUM_CRO = Pair("QTUM_CRO", price_precision=3, quantity_precision=2)
 QTUM_USDT = Pair("QTUM_USDT", price_precision=4, quantity_precision=4)
 REN_CRO = Pair("REN_CRO", price_precision=4, quantity_precision=2)
 REN_USDT = Pair("REN_USDT", price_precision=5, quantity_precision=2)
+SKL_USDT = Pair("SKL_USDT", price_precision=6, quantity_precision=4)
 UNI_CRO = Pair("UNI_CRO", price_precision=3, quantity_precision=2)
 UNI_USDT = Pair("UNI_USDT", price_precision=4, quantity_precision=4)
 USDC_USDT = Pair("USDC_USDT", price_precision=4, quantity_precision=2)
